pygeodesy.ellipsoidalNvector.Ned

Package pygeodesy :: Module ellipsoidalNvector :: Class Ned |
[frames] | no frames]

# Class Ned

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
      ltpTuples._AbcBase --+
                           |
               ltpTuples.Ned --+
                               |
                              Ned

DEPRECATED on 2024.02.04, use class pygeodesy.Ned.

Instance Methods
__init__(self, north, east, down, **name) New Ned vector. |
toRepr(self, prec=None, fmt='[%s]', sep=', ', **unused) DEPRECATED, use class pygeodesy.Ned. |
Inherited from `ltpTuples.Ned`: `to3ned`, `toStr`, `toVector3d` Inherited from `ltpTuples._AbcBase`: `toAer`, `toEnu`, `toNed`, `toXyz` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `ltpTuples.Ned`: `aer4`, `azimuth`, `bearing`, `down`, `east`, `elevation`, `groundrange`, `length`, `ned`, `ned4`, `north`, `slantrange`, `up`, `x`, `xyz4`, `y`, `z` Inherited from `ltpTuples._AbcBase`: `ltp`, `xyz`, `xyz3`, `xyzLocal` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, north, east, down, **name) (Constructor) |
New Ned vector. Arguments: `north_ned` - Scalar North component (`meter`) or a previous local instance (Ned, Ned4Tuple, Aer, Aer4Tuple, Enu, Enu4Tuple, Local9Tuple, XyzLocal or Xyz4Tuple). `east` - Scalar East component (`meter`), only used with scalar `north_ned`. `down` - Scalar Down component, normal to inside surface of the ellipsoid or sphere (`meter`), only used with scalar `north_ned`. `ltp` - The local tangent plane, (geodetic) origin (Ltp, LocalCartesian). `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `north_ned` or `ltp`. `UnitError` - Invalid `north_ned`, `east` or `down`. Overrides: object.__init__ (inherited documentation)

### toRepr (self, prec=None, fmt='[%s]', sep=', ', **unused) |
DEPRECATED, use class pygeodesy.Ned. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `fmt` - Enclosing backets format (`str`). `sep` - Separator between NEDs (`str`). Returns: This Ned as "[L:f, B:degrees360, E:degrees90]" (`str`) with length or slantrange `L`, bearing or azimuth `B` and elevation `E`. Decorators: `@deprecated_method` Overrides: named._Named.toRepr